@@ -278,23 +278,24 @@ def pip(pkgs, ali, douban, upgrade, hide, virtualenv):
              help_options_color='cyan',
              short_help='simplified git pipeline')
 @click.option('-p', '--push', is_flag=True, help='push change to remote')
+@click.option('-c', '--commit', is_flag=True, help='commit change')
 @click.option('-b', '--beautify', is_flag=True, help='beautify code')
 @click.option('-m', '--msg', help='message')
-@click.option('-doc', '--doc', is_flag=True, help='show git tutorials')
-@click.option('-c', '--cache', is_flag=True, help='remove cached files')
+@click.option('--doc', is_flag=True, help='show git tutorials')
+@click.option('--cache', is_flag=True, help='remove cached files')
 @click.option('-l', '--lock', is_flag=True, help='remove index.lock')
 @click.option('-t', '--tag', help='git tag')
-def git(push, msg, beautify, cache, lock, tag, doc):
+def git(push, msg, beautify, commit, cache, lock, tag, doc):
+    if not msg:
+        # If no massage is given, to use the current time instead
+        msg = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+    if beautify:
+        os.system(f'yapf -irp')
+    if commit:
+        os.system(f'git add . --all;git commit -m "' f'{msg}";')
 
     if push:
-        if not msg:
-            # If no massage is given, to use the current time instead
-            msg = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
-        if beautify:
-            os.system(f'yapf -irp .;git add . --all;git commit -m "'
-                      f'{msg}";git push')
-        else:
-            os.system(f'git add . --all;git commit -m "' f'{msg}";git push')
+        os.system('git push')
 
     if lock:
         # fix bug: fatal: Unable to create 'xxx/.git/index.lock': File exists.
